@@ -1,11 +1,17 @@
 package Unicode::Normalize;
 
+BEGIN {
+    if (ord("A") == 193) {
+	die "Unicode::Normalize not ported to EBCDIC\n";
+    }
+}
+
 use 5.006;
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 our $PACKAGE = __PACKAGE__;
 
 require Exporter;
